diff --git a/x264.c b/x264.c
index c1728f1..727ed93 100644
--- a/x264.c
+++ b/x264.c
@@ -126,7 +126,7 @@ static void Help( x264_param_t *defaults, int longhelp )
         "Syntax: x264 [options] -o outfile infile [widthxheight]\n"
         "\n"
         "Infile can be raw YUV 4:2:0 (in which case resolution is required),\n"
-        "  or YUV4MPEG 4:2:0 (*.y4m),\n"
+        "  or YUV4MPEG 4:2:0 (*.y4m or --y4m-input specified),\n"
         "  or AVI or Avisynth if compiled with AVIS support (%s).\n"
         "Outfile type is selected by filename:\n"
         " .264 -> Raw bytestream\n"
@@ -363,6 +363,7 @@ static void Help( x264_param_t *defaults, int longhelp )
     H0( "      --level <string>        Specify level (as defined by Annex A)\n" );
     H1( "\n" );
     H1( "  -v, --verbose               Print stats for each frame\n" );
+    H2( "      --y4m-input             Treat input as yuv4mpeg\n" );
     H1( "      --no-progress           Don't show the progress indicator while encoding\n" );
     H0( "      --quiet                 Quiet Mode\n" );
     H1( "      --psnr                  Enable PSNR computation\n" );
@@ -394,6 +395,7 @@ static void Help( x264_param_t *defaults, int longhelp )
 #define OPT_SLOWFIRSTPASS 267
 #define OPT_FULLHELP 268
 #define OPT_FPS 269
+#define OPT_Y4M_INPUT 270
 
 static char short_options[] = "8A:B:b:f:hI:i:m:o:p:q:r:t:Vvw";
 static struct option long_options[] =
@@ -498,6 +500,7 @@ static struct option long_options[] =
     { "sps-id",      required_argument, NULL, 0 },
     { "aud",               no_argument, NULL, 0 },
     { "nr",          required_argument, NULL, 0 },
+    { "y4m-input",         no_argument, NULL, OPT_Y4M_INPUT },
     { "cqm",         required_argument, NULL, 0 },
     { "cqmfile",     required_argument, NULL, 0 },
     { "cqm4",        required_argument, NULL, 0 },
@@ -773,6 +776,9 @@ static int  Parse( int argc, char **argv,
             case OPT_SEEK:
                 opt->i_seek = atoi( optarg );
                 break;
+            case OPT_Y4M_INPUT:
+                b_y4m = 1;
+                break;
             case 'o':
                 if( !strncasecmp(optarg + strlen(optarg) - 4, ".mp4", 4) )
                 {
@@ -931,10 +937,12 @@ generic_option:
     psz = psz_filename + strlen(psz_filename) - 1;
     while( psz > psz_filename && *psz != '.' )
         psz--;
-    if( !strncasecmp( psz, ".avi", 4 ) || !strncasecmp( psz, ".avs", 4 ) )
-        b_avis = 1;
-    if( !strncasecmp( psz, ".y4m", 4 ) )
-        b_y4m = 1;
+    if( !b_y4m ) {
+        if( !strncasecmp( psz, ".avi", 4 ) || !strncasecmp( psz, ".avs", 4 ) )
+            b_avis = 1;
+        if( !strncasecmp( psz, ".y4m", 4 ) )
+            b_y4m = 1;
+    }
 
     if( !(b_avis || b_y4m) ) // raw yuv
     {
